@@ -20,7 +20,4 @@
 # Modified by Yusuf Kaka <yusufk at gmail>
 # Added support for Optional TLV's
 
-import smpp
-import pdu
-import command
-import client
+from smpplib import client, command, exceptions, pdu, smpp
