@@ -22,59 +22,26 @@
 
 """SMPP module"""
 
-import pdu
+from smpplib import command, pdu
 
 
-smpp_instance = None
-
-
-def make_pdu(command_name, **args):
+def make_pdu(command_name, **kwargs):
     """Return PDU instance"""
 
-    f = pdu.factory(command_name, **(args))
+    f = command.factory(command_name, **kwargs)
 
     return f
 
 
-def parse_pdu(data):
+def parse_pdu(data, **kwargs):
     """Parse binary PDU"""
 
-    command = pdu.PDU.extract_command(data)
+    command = pdu.extract_command(data)
 
     if command is None:
         return None
 
-    new_pdu = make_pdu(command)
+    new_pdu = make_pdu(command, **kwargs)
     new_pdu.parse(data)
 
     return new_pdu
-
-
-def next_seq():
-    """Return next sequence number"""
-
-    pdu.sequence += 1
-
-    return pdu.sequence
-
-
-def get_instance():
-    """Return SMPP class instance. Singleton design pattern -- let only one
-    instance exist"""
-
-    global smpp_instance
-
-    if smpp_instance is None:
-        smpp_instance = smpp_instance
-# TODO FIXXXXX
-
-    return smpp_instance
-
-
-#
-# Exceptions
-#
-
-class UnknownCommandError(Exception):
-    """Raised when unknown command ID is received"""
-
